$(function () {
    $('body').on('click', 'a.upload_files', function () {
        $(this).parent().find('input[type="file"]').click();
        return false;
    })
    $('body').on('change', 'input.upload_photos_input', function (data) {
        $('.num_selected_photos').html('{text_inp}' + $(this)[0].files.length);
        $(this).parent().append('<input type="hidden" name="ag_action" value="add_photo" />');
    })

    $('body').on('click', 'a.save', function () {
        $.ajax({
            url: '',
            type: 'POST',
            data: new FormData($(this).parents('.form-horizontal')[0]),
            contentType: false,
            cache: false,
            processData: false,
            success: function (result)
            {
                var data = jQuery.parseJSON(result)
                if (data.success) {
                    $('#add_dialog').modal('hide');
                    refreshPhotos();
                }
            }
        });
        $('.num_selected_photos').html('');
        $('body').find('input[name="ag_action"]').remove();

        return false;
    });
})
