{photos}
<div class="photoitem" style="background: url({photo}) no-repeat center center / 148px auto" id="photo-{id_photo}">
    <div class="bottom_foto">
        <a href="{photo}" class="fancybox"><i class="icon-search icon-white"></i> {name}</a><br />
        <a href="#{id_photo}" class="btn-del"><i class="icon-trash icon-white"></i> {ln_del}</a><br />
        <a class="btn-edit" href="#{id_photo}"><i class="icon-pencil icon-white"></i> {ln_edit}</a>
    </div>
</div>
{/photos}